function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

//
//
//
//
//
//
//
var script = {
  name: 'Input',
  props: {
    value: {
      type: Boolean,
      required: false,
      default: false
    },
    onblurAppend: {
      type: Boolean,
      required: false,
      default: false
    },
    inputInitValue: {
      type: [String, Number],
      required: false,
      default: ''
    },
    ids: {
      type: Number,
      required: false
    },
    placeholder: {
      type: String,
      required: false,
      default: ''
    }
  },

  data() {
    return {
      inputValue: ''
    };
  },

  methods: {
    outerValue() {
      if (this.inputValue) {
        this.$emit('outerValue', {
          value: this.inputValue,
          ids: this.itemId
        }, () => {
          this.inputValue = ''; // 防止事件冲突

          this.itemId = undefined;
        });
      }
    },

    blurInput() {
      if (this.onblurAppend) {
        this.outerValue();
        this.$emit('input', false);
      } else {
        // 如果是当前已存在的label失去焦点，则还原之前数据
        if (this.itemId !== undefined) {
          this.inputValue = this.inputInitValue;
          this.outerValue();
        }

        this.$emit('input', false);
      }
    }

  },
  computed: {
    inputWidth() {
      return 20 + (this.placeholder.length || this.inputValue.length) * 15;
    }

  },
  watch: {
    value(flag) {
      if (flag) {
        this.$refs.input.focus();
      }
    }

  },

  created() {
    this.inputValue = this.inputInitValue;
    this.itemId = this.ids;
  }

};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier
/* server only */
, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
  if (typeof shadowMode !== 'boolean') {
    createInjectorSSR = createInjector;
    createInjector = shadowMode;
    shadowMode = false;
  } // Vue.extend constructor export interop.


  const options = typeof script === 'function' ? script.options : script; // render functions

  if (template && template.render) {
    options.render = template.render;
    options.staticRenderFns = template.staticRenderFns;
    options._compiled = true; // functional template

    if (isFunctionalTemplate) {
      options.functional = true;
    }
  } // scopedId


  if (scopeId) {
    options._scopeId = scopeId;
  }

  let hook;

  if (moduleIdentifier) {
    // server build
    hook = function (context) {
      // 2.3 injection
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
      // 2.2 with runInNewContext: true

      if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
        context = __VUE_SSR_CONTEXT__;
      } // inject component styles


      if (style) {
        style.call(this, createInjectorSSR(context));
      } // register component module identifier for async chunk inference


      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    }; // used by ssr in case component is cached and beforeCreate
    // never gets called


    options._ssrRegister = hook;
  } else if (style) {
    hook = shadowMode ? function (context) {
      style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
    } : function (context) {
      style.call(this, createInjector(context));
    };
  }

  if (hook) {
    if (options.functional) {
      // register for functional component in vue file
      const originalRender = options.render;

      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      // inject component registration as beforeCreate hook
      const existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }

  return script;
}

const isOldIE = typeof navigator !== 'undefined' && /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());

function createInjector(context) {
  return (id, style) => addStyle(id, style);
}

let HEAD;
const styles = {};

function addStyle(id, css) {
  const group = isOldIE ? css.media || 'default' : id;
  const style = styles[group] || (styles[group] = {
    ids: new Set(),
    styles: []
  });

  if (!style.ids.has(id)) {
    style.ids.add(id);
    let code = css.source;

    if (css.map) {
      // https://developer.chrome.com/devtools/docs/javascript-debugging
      // this makes source maps inside style tags work properly in Chrome
      code += '\n/*# sourceURL=' + css.map.sources[0] + ' */'; // http://stackoverflow.com/a/26603875

      code += '\n/*# sourceMappingURL=data:application/json;base64,' + btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) + ' */';
    }

    if (!style.element) {
      style.element = document.createElement('style');
      style.element.type = 'text/css';
      if (css.media) style.element.setAttribute('media', css.media);

      if (HEAD === undefined) {
        HEAD = document.head || document.getElementsByTagName('head')[0];
      }

      HEAD.appendChild(style.element);
    }

    if ('styleSheet' in style.element) {
      style.styles.push(code);
      style.element.styleSheet.cssText = style.styles.filter(Boolean).join('\n');
    } else {
      const index = style.ids.size - 1;
      const textNode = document.createTextNode(code);
      const nodes = style.element.childNodes;
      if (nodes[index]) style.element.removeChild(nodes[index]);
      if (nodes.length) style.element.insertBefore(textNode, nodes[index]);else style.element.appendChild(textNode);
    }
  }
}

/* script */
const __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", { staticClass: "input-box" }, [
    _c("input", {
      directives: [
        {
          name: "model",
          rawName: "v-model",
          value: _vm.inputValue,
          expression: "inputValue"
        }
      ],
      ref: "input",
      style: { width: _vm.inputWidth + "px" },
      attrs: { placeholder: _vm.placeholder },
      domProps: { value: _vm.inputValue },
      on: {
        blur: _vm.blurInput,
        keypress: function($event) {
          if (
            !$event.type.indexOf("key") &&
            _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")
          ) {
            return null
          }
          return _vm.outerValue($event)
        },
        input: function($event) {
          if ($event.target.composing) {
            return
          }
          _vm.inputValue = $event.target.value;
        }
      }
    })
  ])
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  const __vue_inject_styles__ = function (inject) {
    if (!inject) return
    inject("data-v-1d4aad9f_0", { source: "\n.input-box[data-v-1d4aad9f] {\n  display: inline-block;\n}\ninput[data-v-1d4aad9f] {\n  position: relative;\n  border: none;\n  outline: 0;\n  max-width: 90%;\n}\n", map: {"version":3,"sources":["/home/travis/build/Mayness/vue-tag-fields/src/lib/Input.vue"],"names":[],"mappings":";AAwFA;EACA,qBAAA;AACA;AACA;EACA,kBAAA;EACA,YAAA;EACA,UAAA;EACA,cAAA;AACA","file":"Input.vue","sourcesContent":["<template>\n  <div class=\"input-box\">\n    <input ref=\"input\" @blur=\"blurInput\" @keypress.enter=\"outerValue\" v-model=\"inputValue\"\n      :style=\"{ width: `${inputWidth}px` }\" :placeholder=\"placeholder\"/>\n  </div>\n</template>\n\n<script>\nexport default {\n  name: 'Input',\n  props: {\n    value: {\n      type: Boolean,\n      required: false,\n      default: false\n    },\n    onblurAppend: {\n      type: Boolean,\n      required: false,\n      default: false,\n    },\n    inputInitValue: {\n      type: [ String, Number ],\n      required: false,\n      default: ''\n    },\n    ids: {\n      type: Number,\n      required: false\n    },\n    placeholder: {\n      type: String,\n      required: false,\n      default: '',\n    },\n  },\n  data() {\n    return {\n      inputValue: ''\n    };\n  },\n  methods: {\n    outerValue() {\n      if (this.inputValue) {\n        this.$emit('outerValue', {\n          value: this.inputValue,\n          ids: this.itemId\n        }, () => {\n          this.inputValue = '';\n          // 防止事件冲突\n          this.itemId = undefined;\n        });\n      }\n    },\n    blurInput() {\n      if (this.onblurAppend) {\n        this.outerValue();\n        this.$emit('input', false);\n      } else {\n        // 如果是当前已存在的label失去焦点，则还原之前数据\n        if (this.itemId !== undefined) {\n          this.inputValue = this.inputInitValue;\n          this.outerValue();\n        }\n        this.$emit('input', false);\n      }\n    },\n  },\n  computed: {\n    inputWidth() {\n      return 20 + (this.placeholder.length || this.inputValue.length) * 15;\n    },\n  },\n  watch: {\n    value(flag) {\n      if (flag) {\n        this.$refs.input.focus();\n      }\n    },\n  },\n  created() {\n    this.inputValue = this.inputInitValue;\n    this.itemId = this.ids;\n  },\n};\n</script>\n\n<style scoped>\n.input-box {\n  display: inline-block;\n}\ninput {\n  position: relative;\n  border: none;\n  outline: 0;\n  max-width: 90%;\n}\n</style>"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__ = "data-v-1d4aad9f";
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__ = normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    createInjector,
    undefined,
    undefined
  );

var script$1 = {
  name: 'TagFields',
  props: {
    value: {
      type: Array,
      required: true
    },
    placeholder: {
      type: String,
      required: false
    },
    disabled: {
      type: Boolean,
      required: false
    },
    'max-tag-length': {
      type: Number,
      required: false
    },
    'allow-duplicates': {
      type: Boolean,
      required: false,
      default: true
    },
    'ready-only': {
      type: Boolean,
      required: false,
      default: false
    },
    'onblur-append': {
      type: Boolean,
      required: false,
      default: false
    },
    'before-change': {
      type: Function,
      required: false
    }
  },

  data() {
    return {
      active: false,
      touchIndex: null,
      readyOnlyIndex: -1
    };
  },

  methods: {
    touchItem(key) {
      if (this.readyOnlyIndex <= key) {
        this.touchIndex = key;
      }
    },

    focusBox(e) {
      if (this.disabled) {
        e.stopPropagation();
      } else {
        this.active = true;
      }
    },

    outerValue(_ref, cb) {
      var _this = this;

      var {
        value,
        ids
      } = _ref;
      return _asyncToGenerator(function* () {
        var flag = ids !== undefined; // 校验tag是否超过限制，只校验新增情况

        if (_this.maxTagLength && !flag && _this.data.length >= _this.maxTagLength) return; // 校验是否有重复tag

        if (!_this.allowDuplicates) {
          var index = _this.data.indexOf(value); // 如果找到有相同的数 并且 该位不是原本位置


          if (index > -1 && index !== ids) return;
        }

        var pos = flag ? ids : _this.data.length;
        var deletes = flag ? 1 : 0;

        if (_this.changeData(pos, deletes, value)) {
          _this.touchIndex = null;
          cb();
        }
      })();
    },

    changeData(pos) {
      var deletes = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      var value = arguments.length > 2 ? arguments[2] : undefined;

      if (this.beforeChange) {
        var flag = this.beforeChange(value, pos);
        if (flag !== true) return;
      }

      if (value) {
        this.data.splice(pos, deletes, value);
      } else {
        this.data.splice(pos, deletes);
      }

      this.$emit('change', value, pos, this.data);
      return true;
    },

    deleteItem(key) {
      this.changeData(key, 1);
    }

  },
  computed: {
    data: {
      get() {
        return this.value;
      }

    }
  },

  created() {
    this.readyOnlyIndex = this.readyOnly ? this.value.length : -1;
  },

  components: {
    Input: __vue_component__
  }
};

/* script */
const __vue_script__$1 = script$1;

/* template */
var __vue_render__$1 = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    {
      class: [
        "vTag-box",
        _vm.disabled ? "disabled" : _vm.active ? "active" : ""
      ],
      on: { click: _vm.focusBox }
    },
    [
      _vm._l(_vm.data, function(item, key) {
        return _c(
          "div",
          {
            key: key,
            staticClass: "tag-label-box",
            on: {
              click: function($event) {
                return _vm.touchItem(key)
              }
            }
          },
          [
            _vm.touchIndex !== key
              ? _c("div", { staticClass: "tag-label" }, [
                  _vm._v("\n      " + _vm._s(item) + "\n      "),
                  !_vm.disabled && _vm.readyOnlyIndex <= key
                    ? _c(
                        "span",
                        {
                          staticClass: "delete",
                          on: {
                            click: function($event) {
                              $event.stopPropagation();
                              return _vm.deleteItem(key)
                            }
                          }
                        },
                        [_vm._v("×")]
                      )
                    : _vm._e()
                ])
              : _c("Input", {
                  attrs: {
                    inputInitValue: item,
                    ids: key,
                    onblurAppend: _vm.onblurAppend
                  },
                  on: { outerValue: _vm.outerValue },
                  model: {
                    value: _vm.active,
                    callback: function($$v) {
                      _vm.active = $$v;
                    },
                    expression: "active"
                  }
                })
          ],
          1
        )
      }),
      _vm._v(" "),
      _vm.touchIndex === null
        ? _c("Input", {
            attrs: {
              onblurAppend: _vm.onblurAppend,
              placeholder: _vm.data.length ? "" : _vm.placeholder
            },
            on: { outerValue: _vm.outerValue },
            model: {
              value: _vm.active,
              callback: function($$v) {
                _vm.active = $$v;
              },
              expression: "active"
            }
          })
        : _vm._e()
    ],
    2
  )
};
var __vue_staticRenderFns__$1 = [];
__vue_render__$1._withStripped = true;

  /* style */
  const __vue_inject_styles__$1 = function (inject) {
    if (!inject) return
    inject("data-v-938b81c8_0", { source: "\n.tag-label[data-v-938b81c8] {\n  display: inline-block;\n  position: relative;\n  font-size: 12px;\n  background: #f7f7f7;\n  border: 1px solid #e8eaec;\n  border-radius: 3px;\n  padding: 1px 4px;\n  margin: 1px 5px 2px 0;\n}\n.delete[data-v-938b81c8] {\n  margin-left: 2px;\n  cursor: pointer;\n  color: #666;\n  font-size: 13px;\n}\n.vTag-box[data-v-938b81c8] {\n  position: relative;\n  border: 1px solid;\n  padding: 2px 4px 3px;\n  border: 1px solid #dcdee2;\n  border-radius: 4px;\n  min-height: 25px;\n}\n.vTag-box > div[data-v-938b81c8] {\n  display: inline-block;\n}\n.vTag-box[data-v-938b81c8]:not(.disabled):hover {\n  border-color: #57a3f3;\n}\n.vTag-box.active[data-v-938b81c8] {\n  border-color: #57a3f3;\n  box-shadow: 0 0 0 2px rgba(45, 140, 240, 0.2);\n}\n.vTag-box.disabled[data-v-938b81c8]::after {\n  content: '';\n  cursor: not-allowed;\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  background: rgba(0, 0, 0, .3);\n}\n", map: {"version":3,"sources":["/home/travis/build/Mayness/vue-tag-fields/src/lib/TagFields.vue"],"names":[],"mappings":";AA6HA;EACA,qBAAA;EACA,kBAAA;EACA,eAAA;EACA,mBAAA;EACA,yBAAA;EACA,kBAAA;EACA,gBAAA;EACA,qBAAA;AACA;AACA;EACA,gBAAA;EACA,eAAA;EACA,WAAA;EACA,eAAA;AACA;AACA;EACA,kBAAA;EACA,iBAAA;EACA,oBAAA;EACA,yBAAA;EACA,kBAAA;EACA,gBAAA;AACA;AACA;EACA,qBAAA;AACA;AACA;EACA,qBAAA;AACA;AACA;EACA,qBAAA;EACA,6CAAA;AACA;AACA;EACA,WAAA;EACA,mBAAA;EACA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,WAAA;EACA,YAAA;EACA,6BAAA;AACA","file":"TagFields.vue","sourcesContent":["<template>\n  <div :class=\"[ 'vTag-box', disabled ? 'disabled' : active ? 'active' : '' ]\" @click=\"focusBox\">\n    <div class=\"tag-label-box\" @click=\"touchItem(key)\" v-for=\"(item, key) in data\" :key=\"key\">\n      <div v-if=\"touchIndex !== key\" class=\"tag-label\">\n        {{item}}\n        <span v-if=\"!disabled && readyOnlyIndex <= key\" class=\"delete\" @click.stop=\"deleteItem(key)\">×</span>\n      </div>\n      <Input v-else v-model=\"active\" :inputInitValue=\"item\" :ids=\"key\" @outerValue=\"outerValue\" :onblurAppend=\"onblurAppend\" />\n    </div>\n    <Input v-if=\"touchIndex === null\" v-model=\"active\" @outerValue=\"outerValue\" :onblurAppend=\"onblurAppend\"\n      :placeholder=\"data.length ? '' : placeholder\" />\n  </div>\n</template>\n\n<script>\nimport Input from './Input';\nexport default {\n  name: 'TagFields',\n  props: {\n    value: {\n      type: Array,\n      required: true,\n    },\n    placeholder: {\n      type: String,\n      required: false\n    },\n    disabled: {\n      type: Boolean,\n      required: false,\n    },\n    'max-tag-length': {\n      type: Number,\n      required: false,\n    },\n    'allow-duplicates': {\n      type: Boolean,\n      required: false,\n      default: true\n    },\n    'ready-only': {\n      type: Boolean,\n      required: false,\n      default: false\n    },\n    'onblur-append': {\n      type: Boolean,\n      required: false,\n      default: false\n    },\n    'before-change': {\n      type: Function,\n      required: false\n    }\n  },\n  data() {\n    return {\n      active: false,\n      touchIndex: null,\n      readyOnlyIndex: -1,\n    };\n  },\n  methods: {\n    touchItem(key) {\n      if (this.readyOnlyIndex <= key) {\n        this.touchIndex = key;\n      }\n    },\n    focusBox(e) {\n      if (this.disabled) {\n        e.stopPropagation();\n      } else {\n        this.active = true;\n      }\n    },\n    async outerValue({ value, ids }, cb) {\n      const flag = ids !== undefined;\n      // 校验tag是否超过限制，只校验新增情况\n      if (this.maxTagLength && !flag && this.data.length >= this.maxTagLength) return;\n      // 校验是否有重复tag\n      if (!this.allowDuplicates) {\n        const index = this.data.indexOf(value);\n        // 如果找到有相同的数 并且 该位不是原本位置\n        if (index > -1 && index !== ids) return;\n      }\n\n      const pos = flag ? ids : this.data.length;\n      const deletes = flag ? 1 : 0;\n      if (this.changeData(pos, deletes, value)) {\n        this.touchIndex = null;\n        cb();\n      }\n    },\n    changeData(pos, deletes = 0, value) {\n      if (this.beforeChange) {\n        const flag = this.beforeChange(value, pos);\n        if (flag !== true) return;\n      }\n      if (value) {\n        this.data.splice(pos, deletes, value);\n      } else {\n        this.data.splice(pos, deletes);\n      }\n      this.$emit('change', value, pos, this.data);\n      return true;\n    },\n    deleteItem(key) {\n      this.changeData(key, 1);\n    }\n  },\n  computed: {\n    data: {\n      get() {\n        return this.value;\n      },\n    }\n  },\n  created() {\n    this.readyOnlyIndex = this.readyOnly ? this.value.length : -1;\n  },\n  components: { Input }\n};\n</script>\n\n<style scoped>\n.tag-label {\n  display: inline-block;\n  position: relative;\n  font-size: 12px;\n  background: #f7f7f7;\n  border: 1px solid #e8eaec;\n  border-radius: 3px;\n  padding: 1px 4px;\n  margin: 1px 5px 2px 0;\n}\n.delete {\n  margin-left: 2px;\n  cursor: pointer;\n  color: #666;\n  font-size: 13px;\n}\n.vTag-box {\n  position: relative;\n  border: 1px solid;\n  padding: 2px 4px 3px;\n  border: 1px solid #dcdee2;\n  border-radius: 4px;\n  min-height: 25px;\n}\n.vTag-box > div {\n  display: inline-block;\n}\n.vTag-box:not(.disabled):hover {\n  border-color: #57a3f3;\n}\n.vTag-box.active {\n  border-color: #57a3f3;\n  box-shadow: 0 0 0 2px rgba(45, 140, 240, 0.2);\n}\n.vTag-box.disabled::after {\n  content: '';\n  cursor: not-allowed;\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n  background: rgba(0, 0, 0, .3);\n}\n</style>\n"]}, media: undefined });

  };
  /* scoped */
  const __vue_scope_id__$1 = "data-v-938b81c8";
  /* module identifier */
  const __vue_module_identifier__$1 = undefined;
  /* functional template */
  const __vue_is_functional_template__$1 = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  const __vue_component__$1 = normalizeComponent(
    { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
    __vue_inject_styles__$1,
    __vue_script__$1,
    __vue_scope_id__$1,
    __vue_is_functional_template__$1,
    __vue_module_identifier__$1,
    false,
    createInjector,
    undefined,
    undefined
  );

var Option = {
  install(Vue) {
    Vue.component('TagFields', __vue_component__$1);
  }

};

export default Option;
export { __vue_component__$1 as TagFields };
